package CF2022::Controller::Lists;
use Mojo::Base 'Mojolicious::Controller';
use Mojo::UserAgent;

sub options {
    my $c = shift->openapi->valid_input or return;

    my $args = $c->validation->output;

    my @options = ();

    my $url = sprintf ('%s/organizers/%s/events/%s/',
        $c->config->{pretix_api},
        $c->config->{pretix_organizer},
        $c->config->{pretix_event},
    );

    if ( $args->{type} eq 'products' ) {
        $url .= 'items/';
    }
    if ( $args->{type} eq 'variations' ) {
        $url .= 'items/' . $args->{product_id} . '/variations/';
    }
    elsif ( $args->{type} eq 'questions' ) {
        $url .= 'questions/';
    }

    my $ua = Mojo::UserAgent->new;

    my $records = $ua->get( $url, {
        Authorization => 'Token ' . $c->config->{pretix_token}
    } )->result->json;

    RECORD:
    foreach my $record ( @{ $records->{results} } ) {
        if ( $args->{type} eq 'products' ) {
            next RECORD if ! $record->{active};
            next RECORD if $args->{category_id} && $record->{category} != $args->{category_id};
            push @options, {
               value => $record->{id},
               label => $record->{name}{en},
               price => $record->{default_price} + 0,
            };
        }
        elsif ( $args->{type} eq 'questions' ) {
            next RECORD if $record->{hidden};
            push @options, {
               value => $record->{id},
               label => $record->{question}{en},
               price => 0,
            };
        }
        elsif ( $args->{type} eq 'variations' ) {
            next RECORD if $record->{hidden};
            push @options, {
               value => $record->{id},
               label => $record->{value}{en},
               price => $record->{price} + 0,
            };
        }
    }



    $c->render(openapi => \@options);
}

1;
